# aitx


[![](https://img.shields.io/travis/jeroyang/aitx.svg)](https://travis-ci.org/jeroyang/aitx)
[![](https://img.shields.io/pypi/v/aitx.svg)](https://pypi.python.org/pypi/aitx)

The toolbox for general ML projects

## Features

* TODO

## Installation

```bash
$ python setup.py install
```

## Usage
```python
from aitx) import *
```
## License
* Free software: MIT license
